# -------------------------------------
# Script: example_plotting.R
# Author: Michal Kvasnička
# Purpose: This script shows how to plot prices.
#
# Copyright(c) Masaryk University
# -------------------------------------

# nahraj potřebné balíky a funkce
library(purrr)
source("R/graphing_functions.R")

# načti potřebná data
load("data/pumpdroid_data.RData")

# pro interaktivní grafy odkomentujte následující řádek
# tmap_mode("view")

# průměrné ceny v okresech v jednom období
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30")


# průměrné ceny v krajích v jednom období
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "kraje",
                        existence = "station_exists_30")


# mediánové ceny v okresech v jednom období
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30",
                        stat = median)


# směrodatná odchylka cen v okresech v jednom období
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30",
                        stat = sd)


# průměrné ceny v okresech přes několik období
natural_monthly %>%
    filter(from_date >= "2018-01-01", from_date <= "2018-12-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30")


# vývoj průměrných cen v okresech v čase: průměrné ceny za jednotlivá období
#   v jednotlivých grafech
natural_monthly %>%
    filter(from_date >= "2018-01-01", from_date <= "2018-06-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30",
                        facet = TRUE, facet_col = 2)





# ceny na jednotlivých čerpacích statnicích v jednom období
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_station_prices(existence = "station_exists_30")


# ceny na jednotlivých čerpacích statnicích v jednom období s vykreslením obrysu
# země
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "cr",
                        existence = "station_exists_30")


# ceny na jednotlivých čerpacích statnicích v jednom období s vykreslením obrysů
# okresů
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "okresy",
                        existence = "station_exists_30")


# průměrné ceny na jednotlivých čerpacích statnicích za víc období s vykreslením
# obrysů okresů
natural_monthly %>%
    filter(from_date >= "2018-01-01", from_date <= "2018-12-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "okresy",
                        existence = "station_exists_30")


# ceny na jednotlivých čerpacích statnicích za víc období vykreslené do různých
# grafů s vykreslením obrysů okresů
natural_monthly %>%
    filter(from_date >= "2018-01-01", from_date <= "2018-06-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "okresy",
                        existence = "station_exists_30",
                        facet = TRUE, facet_col = 2)


# ceny na jednotlivých čerpacích stanicích za jedno období -- na pozadí průměrné
# ceny v daném regionu
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "okresy",
                        existence = "station_exists_30",
                        plot_regional_averages = TRUE,
                        regional_averages_alpha = 0.3)


# ceny na jednotlivých čerpacích stanicích za jedno období -- na pozadí průměrné
# ceny v daném regionu -- puntíky cen mají jinou barvu a jsou větší
natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_station_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        regions = "okresy",
                        existence = "station_exists_30",
                        plot_regional_averages = TRUE,
                        regional_averages_alpha = 0.3,
                        palette = "Blues", size = 0.08)





# uložení grafu -- detaily v dokumentaci funkce tmap_save()
# průměrné ceny v okresech v jednom období
p <- natural_monthly %>%
    filter(from_date == "2018-01-01") %>%
    plot_average_prices(arccr_folder = "map_shapes/AdministrativniCleneni_v13.gdb/",
                        existence = "station_exists_30")
tmap_save(p, filename = "fig01.png")
