# Tento skript shromažďuje pokyny pro ruční korekci dat.

# Obsahuje tyto korekční tabulky:
# 1. sjednocování zadávání jmen
# 2. pokyny pro vyhození a sjednocení id čerpacích stanic
# 3. spojení čerpacích stanic, které jsou zadané víckrát nebo kterým se mění id
# 4. ruční opravy jmen čerpacích stanic
# 5. brute-force korekce jmen čerpacích stanic


# vyčisti workspace
rm(list = ls())


# načti potřebné balíky a funkce
library(tibble)
library(dplyr)
library(purrr)
library(stringr)
source("R/preparatory_functions_pumpdroid.R")


# adresáře a soubory
DATADIR <- "data"
CODEDIR <- "R"
OUTPUTFILE <- "handmade_corrections_pumpdroid.RData"





# konstanty -------------------------------------------------------------------------

# datumy pro záměnu "start" a "end" v pumpdroid_stations_to_be_united
start_date <- "1989-01-01"
end_date <- "3001-12-31"





# sjednocení zadaných jmen čerpacích stanic -----------------------------------------

# Jména čerpacích stanic jsou zadána humpolácky. Proto je třeba je jednotit.
# Seznam pumpdroid_station_names_to_be_unified obsahuje seznam všech známých
# variant jmen čerpacích stanic -- vždy každý dílčí atomický vektor odpovídá
# jedné značce. Všechny výskyty všech jmen v každém atomickém vektoru se nahradí
# prvním prvkem tohoto vektoru (na pořadí tedy ZÁLEŽÍ).
#
# Příklad: všechny výskyty "ab oil" a "ab - oil" se nahradí "ab oil", které je
# ve vektoru první.
#
# nevyřešená jména:
# - ami, ami trade
# - as, as praha, as24
# - ats, ats company, ats24-cz
# - bonett, bonett cng station, bonett eurogas cng, bonnet gas investment
# - cesky, cesky plyn
# - cg, cg01
# - cng, cng+
# - various čsad
# - eko, eko - sab
# - ekobus, ekobus litvinov
# - různá zemědělská družstva (a jejich jména s překlepy)
#
# TODO: seznam jmen čerpacích stanic, které mají být sjednoceny, se musí doplnit
#   po každém doplnění dat
pumpdroid_station_names_to_be_unified <- list(
    c("ab oil", "ab - oil"),
    c("agip", "agip gas", "eni oil", "eni", "agip (eni)", "?eni"),
    c("agro žamberk", "agro zamberk"),
    c("ahold - albert", "ahold - euro oil"),
    c("albeva morava", "albeva"),
    c("alitron", "alitron neubuz"),
    c("amigo", "amigo - saly truck"),
    c("amodo","amodo - phm", "amodo phm"),
    c("arex", "arex cz"),
    c("arriva", "arriva vých. čechy", "arriva východní čechy"),
    c("armex oil", "armex oil d1", "armex", "armex merin", "armex měrřín"),
    c("artweld", "artwel"),
    c("a+s", "a + s", "a+s nová"),
    c("as24", "as 24", "as24 novotny"),
    c("auto janak", "auto janák"),
    c("autoshop paulus", "autosnap paulus"),
    c("av tank", "av tank - čepro"),
    c("avanz", "avans"),
    c("avia", "eigl-avia"),
    c("avk štramberk", "atk štramberk", "avk štramberk petrocard czech"),
    c("ax oil", "ax-oil"),
    c("balírna t. pňovice", "balírna t pňovice"),
    c("ballans/bruto", "bruto", "ballance", "ballans"),
    c("b.c.s.", "b.c.s. slovnaft"),
    c("b.r.g.", "b.r.g", "b.r.g. / čepro"),
    c("benz", "benz spol. s r.o."),
    c("benzina", "benzina - expres 24", "star (benzina)",
      "benzina budišov", "benzina plus", "benzina roznov",
      "terno - benzina", "benzina i/56", "benzina express 24"),
    c("bexon", "bexon.", "sandra - bexom", "bexom"),
    c("bilovice", "bílovice"),
    c("bliska", "bliska pl", "blizka"),
    c("bors", "bors břeclav", "bors mikulov"),
    c("boxit", "boxit kájov"),
    c("bsv", "bsv - sjezd z dálnice na lázně bohdaneč"),
    c("bürger transport", "burger"),
    c("bus line", "busline"),
    c("cds nachod", "cds náchod"),
    c("cobalt", "benzinka kozojedy", "benzinka kozojedy (čepro)",
      "cobalt kozojedy"),
    c("coop", "coop 24", "coop24"),
    c("čerpací stanice", "čerpaci stanice"),
    c("český", "cesky"),
    c("český plyn", "cesky plyn"),
    c("čsad", "csad"),
    c("čsad karviná", "csad karvina", "čsad karvina"),
    c("čsad kladno", "csad kladno"),
    c("čsap nymburk", "čsad nymburk"),
    c("čadek lpg", "čadek"),
    c("čsad hodonín", "čsad hodonin"),
    c("čsad praha holding", "florenc", "čsad praha holding - (florenc)",
      "čsad praha florenc"),
    c("čsao praha", "csao praha"),
    c("delp", "delp spol. - eva lavičková",
      "delp spol. sr. o. - eva lavičková"),
    c("delta oil", "deltaoil"),
    c("dopravní podnik hl.m. prahy", "dp hl.m.prahy"),
    c("dopravní podnik města pardubice", "dopravní podnik města pardubic"),
    c("domo oil", "do mo oil"),
    c("ekobus", "Ekobus Litvinov ekobus litvinov"),
    c("elgé", "elge"),
    c("emil frey", "avia emil frey"),
    c("eon", "e.on energie", "e-on"),
    c("eryx", "eryx oil - elite solutions friends"),
    c("esotank", "esotank exit 128"),
    c("expers24", "expres 24"),
    c("euro plus system", "euro plus", "euro-plus system"),
    c("eurobit", "eurobit - čerpací stanice", "eurobit libor gregor",
      "eurobit oil", "i/11 eurobit"),
    c("eurooil", "čepro", "cepro", "čepro čermák - import export servis",
      "čepro kelčice", "čepro prémiová stanice",
      "čepro prospeed", "euro oil",
      "cepro prospeed", "cobalt - kozojedy (čepro)",
      "euroil", "tolosaner (čepro)"),
    c("eurowag", "u celnice eurowag", "truckpark eurowag", "euorowag",
      "eurowag - u celnice", "ew eurowag"),
    c("f9", "f9 cechotrans", "f9 u nemocnice rakovnik"),
    c("fak oil", "fak oil srnov"),
    c("fato", "fato plus"),
    c("fraba", "fraba diesel", "fraba-diesel"),
    c("framex", "framex cz"),
    c("fill", "fill expres", "fill expres u kauflandu"),
    c("flaga", "flaga - plyn spol. s r.o.", "flaga cesky plyn",
      "flaga čs jemnice", "flaga čs lpg pb trans pardubice",
      "flaga gas", "flaga matousek frantisek", "flaga pejchal",
      "flaga s. r.o.", "flaga sro", "flaga uhelná"),
    c("free 1", "free 1 gas", "free one shop", "free1", "free1 gas",
      "f1 gas", "f1 tir", "f1", "f1 top tank", "ing. falta f1oil", "f1 (top tank)"),
    c("fronk jaroslav", "fronk jarda"),
    c("ftl", "ftl prostějov cng"),
    c("gas petroleum", "g. petroleum", "g .petroleum", "g. peteoleum", "g. petrolem",
      "g.", "gaspetroleum"),
    c("gabi", "gabi - bakeš miloš"),
    c("gas-pro", "gaspro"),
    c("gbagbos system", "gbagbos systém"),
    c("go", "go germania", "go germania oil", "go bohemia", "go!"),
    c("golc", "golc oil"),
    c("g & s", "g&s bludovice"),
    c("hdb", "hdb úpice"),
    c("herst", "herst bobnice", "herst u kauflandu"),
    c("hlíza gas", "hlízagas"),
    c("hos", "hos lipno"),
    c("hostivice", "čechotrans hostivice", "hostivice - unishop plus"),
    c("hruby", "hrubý"),
    c("hs cínovec", "hs cinovec"),
    c("hunsgas", "hungas"),
    c("ina industrija nafte d.d.", "ina industija nafte d.d."),
    c("ing. josef slezák", "ing. josef slezâk"),
    c("icom transport", "icom transort"),
    c("ipari", "ipari park", "ipari park. bilovec /dodavatel čepro/",
      "ipari park studénka"),
    c("jiho oil", "jiho oil jitka huňková"),
    c("jiří fejkl", "jiri fejkl"),
    c("jiří hrachovec", "jiří hrachovec autogasmotors"),
    c("jp oil", "jp servis oil"),
    c("k petrol", "k - petrol"),
    c("k & p", "k & p most - velebudice", "k&p", "k&p čerpací stanice"),
    c("k diskont", "k-diskont"),
    c("k-oil", "k oil - křeček", "k oil křeček"),
    c("k.v.k gas", "k.v.k. gas spol s r. o.", "k.v.k. gas spol. s r. o",
      "k.v.k. gas spol. s r.o."),
    c("km prona", "km - prona", "km-prona"),
    c("karel frolik", "karelfrolik"),
    c("koloc oil", "r4 koloc oil", "protego koloc", "josef koloc",
      "koloc oil - protego", "koloc"),
    c("kontakt", "kontakt - služby motoristum"),
    c("kralupol", "kralupol matousek frantisek",
      "kralupol matousek jaroslav"),
    c("kumegas", "kumegas pb", "kumegas lpg"),
    c("lad oil", "lad oil - čepro"),
    c("lašek", "lašek omw", "lašek omv"),
    c("ledopa", "ledopa oil"),
    c("linde gas", "linde", "linde - lpg", "linde lpg"),
    c("m 2000 produkt", "m 2000 product"),
    c("m&m", "m&m senice"),
    c("mark oil", "markoil"),
    c("martin oil", "martin oil horní počernice"),
    c("mavex", "mavex diesel"),
    c("medos", "medos agro", "medos ina"),
    c("mechanika prostějov 97 družstvo", "mechanika 97 družstvo"),
    c("merkur k", "merkur-k", "merkur hořovice"),
    c("mikra plus", "mikra plus - unishop plus"),
    c("miroslav müller", "miroslav muller"),
    c("m-gas", "m-gas cz", "u macka m-gas cz"),
    c("mjm", "mjm litovel", "mjm uničov", "mjm agro"),
    c("mol", "pap oil -> mol"),
    c("mv plus", "mv plus (berou hotovost )"),
    c("mvd", "mvd spol."),
    c("natankuj", "natankuj - dovozauta"),
    c("niko oil", "miko oil (kasárna v mostě)", "niko oil (kasárna v mostě)"),
    c("nova-kont", "kont", "kont (nova-kont)"),
    c("od impro cerveny kostelec", "od impro červ. kostelec"),
    c("oil team", "oil team - erneks", "oil team ernkes", "oil team (flaga)",
      "oil team erneks", "oilteam", "erneks oil team"),
    c("oktan", "oktan plzeň", "petrol oktan plzeň"),
    c("omv", "omw", "omv bilovice", "omw mcd bb", "ömv"),
    c("ono", "ono areal pohona"),
    c("oreos lpg", "oreos lpg - pjk"),
    c("orlen", "pkn orlen", "pk orlen", "polski koncern naftowy orlen s. a.",
      "pkn orlen s.a.", "bliskaorlen"),
    c("pallas", "pallas cz"),
    c("papoil", "pap oil"),
    c("pasoil", "pas oil"),
    c("pento", "pento oil"),
    c("petr houdek", "houdek", "petrhoudek"),
    c("petrol", "petrol dkvk"),
    c("petroil", "petroil cz"),
    c("petra", "petra plus", "petra plus mrzout oil"),
    c("petrocard", "petrocard czech"),
    c("petrol", "petrol čs", "petrol milicin", "vs petrol"),
    c("pevný a spol", "pevny a"),
    c("phm group", "phmgroup"),
    c("plnírna pb drahanovice", "plnírna pb"),
    c("plus oil", "plusoil", "w8 (plus oil)"),
    c("polfin", "polfin ploština"),
    c("pr", "pr - pavel růžička"),
    c("prim", "alfa station / prim", "hunsgas - prim", "prim petra",
      "petra plusč.s. prim lysá nad labem", "prim - petra",
      "prim lochenice"),
    c("primagas", "primagaz"),
    c("prazske sluzby", "pražské služby"),
    c("pragitrans", "pragitrans-skanska"),
    c("profer plus", "proferplus"),
    c("profi auto", "profi auto cz"),
    c("protego koloc", "protego koloc oil", "protego koloc provoz lisnice",
      "protego s r.o. koloc oil karez", "protego s r.o. koloc oil"),
    c(" první bohdikovska", "první bohdikovska rataj lpg flaga"),
    c("první brdská", "prvni brdska"),
    c("rajchl josef", "rajchl josef ústeckápraha 8 kobylisy"),
    c("rams", "ramš"),
    c("rapid oil", "rapid oil s. r. o"),
    c("rmv", "rmv potučky", "rmv potůčky"),
    c("robin oil", "robinoil"),
    c("rockoil", "rock-oil", "rock oil"),
    c("rokor", "rokor union road"),
    c("rs petrol", "rs", "rs petrole"),
    c("rwe", "rwe cng", "rwe energo", "rwe-cng"),
    c("sab trafo", "sab - trafo", "sab-trafo"),
    c("sap", "sap loket", "sap spol. s r.o"),
    c("shell", "shell - košuty", "shell - mimo provoz",
      "shell (neste a24)", "shell station rath betriebs gmbh",
      "schell"),
    c("silmet", "silmet plus"),
    c("slovácký statek", "slovacky statek"),
    c("slovnaft", "slovnaft záhorská bystrica", "slovnat", "slo-naft"),
    c("sva", "sva třebíč"),
    c("svam", "svam cs", "svam cs (flaga)"),
    c("šafránka", "šafránka praha", "šafránka rudná"),
    c("š+h", "š+h oil"),
    c("tank oil", "tank oil - tesco"),
    c("tank ono", "ono", "ono pneu"),
    c("tankuj 24", "tankuj24"),
    c("tesco", "sleva -1kc tesco"),
    c("tm", "tm čerpací stanice", "tm stav"),
    c("texaco", "texaco - j&h st.", "texaco - j&h station",
      "auto petrol (texaco oleje)", "texaco - auto petrol",
      "auto petrol cz"),
    c("tohoz", "tohoz frigotransport"),
    c("tolosaner", "tolosaner (čepro)"),
    c("tomegas", "tome gas", "tomegas - chválenice",
      "tomegas (uhelné sklady)", "tomegaz", "lpg tom gas", "lpg tomegas"),
    c("total", "total hosek", "total hosek u dpchj",
      "total hosek u garáže dpchj"),
    c("topexol", "topexoil"),
    c("toro vm", "toro"),
    c("totoil", "totoil - petr holota"),
    c("trilobit", "trilobit real"),
    c("ttb", "ttb tisa"),
    c("tukas", "auto masarik (drive tukas)", "škoda-tukas", "škods-tukas",
      "tukas - škoda", "tukas - škoda centrum", "tukas - volkswagen",
      "tukas - volkswagen centrum", "tukas - renault /dacia"),
    c("tvl", "tvl čerpačka mostek"),
    c("u krobiána", "u krobiana"),
    c("u pštrosa", "u pstrosa"),
    c("u zlaté podkovy", "u zlate podkovy"),
    c("uhelné sklady", "uhelne sklady"),
    c("unipetrol", "unipetrol partner", "unipetrolpartner"),
    c("úsovsko", "usovsko"),
    c("variel", "variel a. s"),
    c("vemex", "vemex na zátorce 350/5 prague 6", "vemex gazprom"),
    c("vena trade", "vena-trade", "vena - trade", "vena"),
    c("vendys", "vendys petrol", "vendys & v", "vendys&v"),
    c("vest", "vest slavkov"),
    c("vest oil", "vestoil"),
    c("via kocanda", "via kocanda koblasa"),
    c("vitogaz", "vitogaz čr"),
    c("v. j. station", "v. j. station (texaco)"),
    c("vk program", "vk programwww.vk-program"),
    c("vps vítkovice", "vítkovice doprava"),
    c("w8", "w8 ostatni", "w8-tomegas", "w8 karimpex"),
    c("wágnerová", "wagnerova"),
    c("way 24", "way24", "way24 - gabena"),
    c("z-petrol", "z - petrol"),
    c("zaris", "zaris plzeňská 1972/158 praha 5"),
    c("záruba", "záruba m&k"),
    c("zd častrov", "zd castrov"),
    c("zd městečko trnávka", "d mestecko trnavka", "zd mestecko trnavka"),
    c("zd těšetice", "jzd těšetice"),
    c("zerogas", "zerogas litava", "zerogas litava s r.o", "zerogas plus"),
    c("zod", "zod hořice"),
    c("zzn", "zzn polabí"),
    c("zemědělské družstvo", "zemedelske druzstvo", "zemědělské druźstvo")
)





# vyhození neexistujících čerpacích stanic ------------------------------------------

# Existují minimálně dva důvody, proč čerpací stanice zadané v datech nemusejí
# ve skutečnosti vůbec existovat:

# 1. dvě nebo víc id stanic odpovídá jedné čerpací stanici v realitě; zdá se, že
#   to může vzniknout hlavně ze dvou příčin:
#   (a) čerpací stanice změnila majitele a v mezičase nefungovala; když začala
#   znovu fungovat, dostala nové id;
#   (b) poloha čerpací stanice byla aspoň jednou zaměřena nepřesně, takže někdo
#   zadal stanici jako dvě nebo víc
# 2. čerpací stanice má velmi málo pozorování ve velice úzkém časovém okně; to
#   může znamenat, že stanice je buď podvod, nebo je mimořádně bezvýznamná
# Stejné stanice jsou buď v datech stejnoceny nebo jsou minoritní pozorování
#   dané stanice vyhozeny z dat. Podvodné a bezvýznamné stanice jsou také
#   eliminovány.

# Zde se vytvoří korekční tabulky, které budou sloužit k opravě těchto tabulek:
# - price_data
# - station_location
# - station_names
# - station_features
# - station_beeline_distances
# - station_<driving>_distances (není asi přesné jméno) ???

# korekční tabulky byly vytvořeny ručně; postup:
# 1. najít všechny stanice, které mají vzdálenost vzdušnou čarou menší než 200 m
#   a pro každou kombinaci takových stanic zkontrolovat, jestli se jedná o jednu
#   nebo víc stanic:
#   (a) zkontrolovat na Google Maps
#   (b) zkontrolovat, že vývoj cen je kompatibilní  # TODO: zatím jen pro
#       Natural 95
# 2. najít stanice, které mají méně než X pozorování a mezi prvním a posledním
#   pozorováním je méně 90 dnů a méně; pro takové stanice pak najít sousedy a
#   (a) zkontrolovat na Google Maps
#   (b) zkontrolovat, že vývoj cen je kompatibilní  # TODO: zatím jen pro
#       Natural 95


# seznam id čerpacích stanic, které mají být odstraněny z dat
# TODO: seznam stanic, které mají být odstraněny se musí opravit po každém
#   přidání dat -- nejen doplnit, ale staré zkontrolovat!
pumpdroid_stations_to_be_removed <- c(
    # --- Michal Kvasnička, 27. května 2019 -- začátek ---
    # čerpací stanice, které měly do roku 2018 5 a méně pozorování v
    # nejsilnějším palivu a poslední pozorování bylo v červnu 2018 nebo dříve
    # stations_with_few_observations %>%
    # filter(obs <= 5, stop_date <= as.Date("2018-06-30")) %>%
    # format_removed_ids()
    946, 989, 1058, 1107, 1433, 1455, 1460, 1466, 1468, 1538, 1560, 1584, 1599,
    1666, 1667, 1674, 1714, 1718, 1730, 1802, 1880, 1979, 2052, 2067, 2100, 2137,
    2146, 2148, 2157, 2174, 2203, 2207, 2218, 2255, 2261, 2274, 2302, 2332, 2342,
    2343, 2345, 2346, 2366, 2762, 2858, 2862, 2889, 2892, 2916, 2925, 2941, 2973,
    3027, 3033, 3059, 3062, 3064, 3069, 3073, 3081, 3089, 3101, 3121, 3122, 3132,
    3139, 3150, 3168, 3171, 3178, 3203, 3227, 3229, 3242, 3262, 3266, 3279, 3292,
    3297, 3311, 3331, 3361, 3389, 3404, 3440, 3449, 3460, 3463, 3465, 3474, 3489,
    3501, 3534, 3576, 3594, 3605, 3642, 3652, 3658, 3666, 3746, 3770, 3785, 3787,
    3843, 3909, 3915, 3930, 3938, 3940, 3948, 3974, 4023, 4078, 4101, 4150, 4202,
    4208, 4213, 4217, 4219, 4220, 4236, 4245, 4268, 4274, 4336, 4437, 4470, 4474,
    4476, 4478, 4597, 4613, 4632, 4636, 4648, 4661, 4662, 4701, 4812, 4814, 4833,
    1695, 3255, 3344, 4462, 1376, 2955, 3415, 3418, 3990, 3516, 3748, 3890, 4605,
    3177, 4640, 3157, 4401, 3969, 3643, 4471, 4002, 4356, 4403, 4691, 3979, 3302,
    4384, 4148, 1595, 2084, 2861, 3179, 3301, 3451, 4512, 2285, 2927, 3436, 3766,
    4222, 4548, 3294, 3180, 3334, 3341, 3744, 4352, 4619, 4407, 3235, 4406, 4690,
    3247, 4003, 4242, 3280, 3525, 4259, 4203, 4244, 2689, 3222, 3586, 2528, 2989,
    4189, 4467, 3245, 3004, 4317, 3103, 3668, 4205, 4335, 2669, 3202, 4130, 4371,
    1576, 2986, 3829, 1448, 4546, 3838, 3243, 3779, 4452, 3220, 4175, 4807, 4490,
    3850, 4695, 1037, 4446, 4450, 3600, 4633, 1110, 4298, 3268, 4093, 4544, 4221,
    2484, 4260, 3854, 4054, 4262, 4399, 4252, 4721, 3557, 4165, 2970, 4464, 3778,
    3260, 4427, 4461, 3985, 3496, 4513, 1531, 4508, 1445, 3896, 2180, 3659, 1108,
    4532, 3735, 3786, 2748, 4111, 3485, 1898, 4531, 1984, 3487, 2225, 108, 4372,
    4134, 2694, 2839, 4443, 3745, 2985, 4488, 1507, 3386, 2329, 1924, 3504, 2259,
    2296, 3034, 3446, 1539, 1678, 2735, 2867, 4629, 3207, 1423, 2254, 2993, 2223,
    4670, 1451, 3665, 1493, 2021, 3943, 1559, 2220, 3517, 4562, 3094, 3824, 2198,
    2638, 2792, 3362, 3798, 2416, 4475, 887, 3238, 4684, 4489, 2063, 1461, 3862,
    2413, 3608, 3049, 3563, 4458, 2310, 2257, 4434, 1834, 3428, 1569, 3313, 1568,
    1872, 4536, 3945, 1556, 1499, 1518, 2050, 2190, 4503, 2696, 1513, 2262, 1482,
    2081, 3416, 4528, 3716, 4012, 4121, 2593, 2331, 1550, 3151, 3224, 4052, 2187,
    3432, 1496, 4147, 2213, 2178, 2221, 4839, 2236, 4838, 4383, 4837, 4836, 2179,
    2224, 4749, 4832, 4724, 4742, 4741, 4760, 2263, 1755, 4786, 4790, 4805, 4820,
    4813, 3097, 4834, 2152, 4090, 2161, 2682, 1797, 2233, 4198, 1713, 1668, 4127,
    4031, 1857, 4748, 2204, 4714, 2191, 4728,
    # čerpací stanice, které měly do roku 2018 5 a méně pozorování v
    # nejsilnějším palivu a poslední pozorování bylo v červenci 2018 nebo
    # později
    # stations_with_few_observations %>%
    # filter(obs <= 5, stop_date > as.Date("2018-06-30")) %>%
    # format_removed_ids()
    4079, 4689, 4555, 4738, 4768, 4620, 4681, 4722, 4069, 4672, 4671, 4669, 4556,
    4519, 4520, 4479, 4377, 3592, 4146, 4108, 4775, 4824, 3514, 4827, 4822,
    # čerpací stanice, které měly do roku 2018 6 až 10 pozorování v nejsilnějším
    # palivu a poslední pozorování bylo v červnu 2018 nebo dříve
    # stations_with_few_observations %>%
    # filter(obs > 5, obs <= 10, stop_date <= as.Date("2018-06-30")) %>%
    # format_removed_ids()
    3970, 3596, 4549, 3500, 4388, 3856, 2881, 2766, 4016, 3555, 3052, 4542, 4466,
    4062, 3794, 4487, 3590, 2194, 3788, 3159, 3636, 3359, 3601, 3781, 2812, 3354,
    4238, 4709, 2755, 3751, 4416, 4574, 4026, 2110, 1930, 1567, 2440, 1437, 2903,
    1404, 685, 1621, 4385, 4064, 681, 2765, 2629, 3826, 3614, 2215, 2711, 1800,
    4133, 2027, 3318, 2176, 1687, 2088, 3265, 3677, 4491, 3971, 1484, 2713, 2102,
    4485, 2313, 2525, 1690, 4687, 1456, 3815, 1429, 3767, 2250, 3458, 1998, 1976,
    4228, 1740, 2177, 1815, 4639, 2833, 2184, 2248, 2949, 1480, 2875, 3549, 1932,
    2347, 1864, 1303, 4497, 2946, 2919, 2286, 1772, 1446, 3314, 2144, 3806, 2772,
    1424, 2276, 1746, 3546, 1679, 2238, 4400, 1535, 4075, 2131, 4300, 2277, 3340,
    1578, 1847, 2094, 2182, 2058, 3371, 1582, 3364, 3453, 3892, 4789, 3963, 4823,
    4141, 3148, 1575, 4084, 2943, 4772, 2020, 4050, 4091, 4030, 1421, 1577, 2231,
    1671, 1544, 2090, 1536, 1322, 4750,
    # čerpací stanice, které měly do roku 2018 11 až 20 pozorování v
    # nejsilnějším palivu, poslední pozorování bylo v červnu 2018 nebo dříve a
    # date_span byl maximálně 100 dnů
        # stations_with_few_observations %>%
    # filter(obs > 10, obs <= 20, stop_date <= as.Date("2018-06-30"),
    #   date_span <= 100) %>%
    #   format_removed_ids()
    4382, 4290, 4100, 3469, 3615, 4527, 3835, 1884, 2408, 1481,
    # čerpací stanice, které měly do roku 2018 21 až 50 pozorování v
    # nejsilnějším palivu, poslední pozorování bylo v červnu 2018 nebo dříve a
    # date_span byl maximálně 100 dnů
        # stations_with_few_observations %>%
    # filter(obs > 20, obs <= 50, stop_date <= as.Date("2018-06-30"),
    #   date_span <= 100) %>%
    #   format_removed_ids()
    3934, 3784, 3667,
    # --- Michal Kvasnička, 27. května 2019 -- konec ---
    #
    # --- Magdaléna Šuterová, červen 2019 -- začátek ---
    3552, # duplicita s id 1073
    3801, # duplicita s id 1655
    4358, # duplicita s id 853
    226, # duplicita s id 181
    3080, # duplicita s id 1025
    4370, # duplicita s id 1025
    4732, # duplicita s id 956
    4801, # duplicita, a ani nemá značku takže ani není jasné čeho je to duplicita
    4725, # duplicita, a ani nemá značku takže ani není jasné čeho je to duplicita
    3726, # duplicita s id 1414
    4818, # duplicita s id 4817
    2124, # duplicita s id 471
    2055, # duplicita s id 143
    4713, # duplicita s is 923
    4579, # duplicita s id 1076
    4568, # duplicita s id 1869
    2082, # duplicita s id 2320
    715, # duplicita s id 2186
    3429, # duplicita s id 2186
    1717, # duplicita s id 894
    2031, # duplicita s id 3041
    1585, # duplicita s id 3236
    4537, # duplicita s id 997
    3448, # duplicita s id 1972
    3319, # duplicita s id 2559
    2460, # duplicita s id 1686
    2111, # duplicita s id 2033
    4535, # duplicita s id 2127
    4594, # duplicita s id 1065
    3632, # duplicita s id 3622
    4777, # duplicita s id 4682
    4688, # duplicita s id 4682
    2172, # duplicita s id 2599
    254, # duplicita s id 261
    1579, # duplicita s id 1775
    4083, # duplicita s id 2872
    2280, # duplicita s 2702
    4683, # duplicita s id 1516
    2828, # duplicita s id 2649
    4560, # duplicita s id 147
    1593, # duplicita s id 2677
    3187, # duplicita s id 2795
    1351, # duplicita s id 1736
    1829, # duplicita s id 1736
    1449, # duplicita s id 1545
    4667, # duplicita s id 2592
    4791, # duplicita s id 4523
    4283, # duplicita s id 4442
    2197, # duplicita s id 2330
    3304, # duplicita s id 1962
    4585, # duplicita s id 2652
    4630, # duplicita s id 4627
    4776, # duplicita s id 3068
    2062, # duplicita s id 1467
    3399, # duplicita s id 1711
    3891, # duplicita s id 2511
    3019, # duplicita s id 2907
    4239, # duplicita s id 2907
    4718, # duplicita s id 3606
    4731, # duplicita s id 3606
    4815, # duplicita s id 1221
    2060, # duplicita s id 2594
    1320, # duplicita s id 548
    4727, # duplicita s id 1842
    4586, # duplicita s id 2040
    4561, # duplicita s id 146
    769, # duplicita s id 770
    231, # duplicita s id 230
    4494, # duplicita s id 3935
    3607, # duplicita s id 3593
    3702, # duplicita s id 1236
    4826, # duplicita s id 3189
    4151, # duplicita s id 2673
    4302, # duplicita s id 2673
    2660, # duplicita s id 1409
    3578, # duplicita s id 2089
    4719, # duplicita s id 1415
    2821, # duplicita s id 2820
    1968, # duplicita s id 1960
    3937, # duplicita s id 2155
    1787, # duplicita s id 2960
    4759, # duplicita s id 1941
    4570, # duplicita
    # --- Magdaléna Šuterová, červen 2019 -- konec ---
    # --- Michal Kvasnička, 2. října 2019 -- začátek
    2199, # tato stanice nemá žádné údaje o ceně
    # --- Michal Kvasnička, 2. října 2019 -- konec ---
    # --- Michal Kvasnička, 15. října 2019 -- začátek
    # tyto stanice nemají skoro žádná pozorování a vznikly se značkou Agip,
    # která v době jejich údajného vzniku vůbec neexistovala
    4757, 4758, 4771, 3957, 4599,
    # tyto stanice mají tak málo pozorování přes všechna paliva (30 a méně ve
    # všech palivech před 30. červnem 2018), že skoro jistě nikdy neexistovaly
    3014, 2898, 1677, 4337, 3964, 2096, 4234, 4183, 2305, 1542, 2162,
    2671, 4678, 4167, 4598, 2712
    # --- Michal Kvasnička, 15. října 2019 -- konec
)


# tabulka id, které jsou podezřelé (= jsou příliš blízko k jiným stanicím), ale
# jsou vpořádku; hodnoty jsou ideálně jedna na řádku s komentářem, proč je o.k.
pumpdroid_stations_close_ok <- c(
  # --- Magdaléna Šuterová -- červen 2019 -- začátek ---
  53, # smíchaná se stanicemi, z nichž vyleze id 1655; stanice jsou naproti sobě přes silnici, tahle ok, ty ostatní se sjednocují
  853, # je ok, jen měla duplicitu 4358 která se vyhazuje
  4334, # naproti sobě přes silnici s id 181
  1025, # měla duplicity ids 3080 a 4370, které se vyhazují
  151,
  664,
  2054, # tyhle tři (151, 664, 2054) jsou asi ok, ale nejspíš je chaos v zadávání dat. diagnose(stations_too_close[[8]]), data pro ceny neodpovídají tomu, jak se to jeví na google maps. Např. 2054 má zaznamenané ceny jen LPG. Asi neřešitelné
  1039, # je ok, ostatní z 13. řádku seznamu se sjednocují
  1975, # je ok, ostatní z 13. řádku seznamu se sjednocují
  2075, # je ok, ostatní z 18. řádku seznamu se sjednocují
  122, # je ok, značka Shell, ale má navíc po jednom pozorování pro paliva verva100 a vervadiesel což jsou od Benziny. Tahle dvě pozorování vyhodit
  1470, # je ok, 24. řádek seznamu má tři stanice
  2372, # asi ok. Je to jen LPG, ale není jasné jestli patří k některé ze stanic, ani google neukazuje, že by nějaká z nich nabízela LPG
  4817, # měla duplicitu 4818, ta se vyhazuje
  31, # vedle sebe s 1919, a s 2099. Ta 2099 je LPG stanice, která stojí fakt přesně vedle, ale nepatří k tomu. V 31 jsou zavedeny ceny i pro LPG, které by tam neměly být.
  1919, # vedle sebe s 31
  471, # měla duplicitu 2124
  1052, # neproti sobě přes silnici s id 471
  143, # měla duplicitu 2055
  1057, # vedle sebe s 2291
  923, # měla duplicitu s 4713
  235, # vedle sebe s id 2326
  1076, # měla duplicitu id 4570
  2076, # vedle sebe s id 3291
  3291, # vedle sebe s id 2076
  1869, # měla duplicitu id 4568
  2320, # měla duplicitu id 2082
  2186, # měla duplicity s ids 715 a 3429
  159, # vedle sebe s id 1396
  1396, # vedle sebe s id 159
  894, # měla duplicitu s id 1717
  2634, # vedle sebe s id 894
  3041, # měla duplicitu s id 2031
  997, # měla duplicitu s id 4537
  1972, # měla duplicitu s id 3448
  2559, # měla duplicitu id 3319; špatně jméno, oprava v samostatném skriptu
  564, # vedle sebe s id 3905
  3905, # vedle sebe s id 564
  1686, # měla duplicitu s id 2460
  2033, # měla duplicitu id 2111
  2127, # měla duplicitu id 4535
  2483, # vedle sebe s id 962
  1279, # vedle sebe s id 1571
  1571, # vedle sebe s id 1279
  372, # vedle sebe s 1065
  1065, # vedle sebe s 372
  4682, # měla duplicity 4688, 4777
  2599, # měla duplicitu 2171
  261, # měla duplicitu 254
  4516, # LPG stanice vedle 261; špatně jméno, oprava v samostatném skriptu
  1775, # měla duplicitu id 1579
  2872, # měla duplicitu id 4083; špatně jméno, oprava v samostatném skriptu
  2702, # měla duplicitu id 2280; špatně jméno, oprava v samostatném skriptu
  194, # vedle sebe s id 2453
  3367, # vedle sebe s id 1729
  1062, # vedle sebe s id 2649
  2649, # vedle sebe s id 1062 & duplicita s id 2828
  147, # měla duplicitu 4560
  528, # vedle sebe s 1405
  1405, # vedle sebe s 528
  4499, # vedle sebe s 2301
  1162, # vedle sebe s 1180, 1394 a 182
  1180, # vedle sebe s 1162, 1394 a 182
  182, # vedle sebe s 1180, 1394 a 1162
  1394, # vedle sebe s 182, 1162, 1180
  1474, # vedle sebe s 2842
  676, # vedle sebe s 2244
  2244, # vedle sebe s 676, oprava jména v samostatném skriptu
  2677, # měla duplicitu id 1593
  2795, # měla duplicitu id 3187
  3031, # vedle sebe s id 1736
  1736, # vedle sebe s id 3031
  1545, # vedle sebe s 2566,
  2566, # vedle sebe s 1545
  309, # vedle sebe s ids 1212 a 2592
  1212, # vedle sebe s ids 2592 a 309
  2592, # vedle sebe s ids 1212 a 309
  225, # vedle sebe s ids 893 a 4442
  893, # vedle sebe s ids 225 a 4442
  4442, # vedle sebe s ids 893 a 225; špatně jméno, oprava v samostatném skriptu
  2330, # měla duplicitu id 2197; špatně jméno, oprava v samostatném skriptu
  4720, # vedle sebe s id 133
  1962, # měla duplicitu s id 3304
  2652, # mela duplicitu 4585
  3761, # vedle sebe s 2652
  4627, # měla duplicitu 4630
  1072, # vedle sebe s id 1483
  158, # vedle sebe s id 4019 a 4174
  4019, # vedle sebe s id 158 a 4174
  4174, # vedle sebe s id 158 a 4019
  206, # vedle sebe s 4387
  4387, # vedle sebe s 206
  2647, # vedle sebe s id 3488
  3488, # vedle sebe s id 2647
  324, # vedle sebe s id 3988
  3988, # vedle sebe s id 324
  3068, # měla duplicitu 4776
  945, # vedle sebe s id 2245
  1467, # měla duplicitu s id 2062
  1711, # měla duplicitu s id 3399
  2907, # měla duplicity ids 3019, 4239
  1184, # vedle sebe s id 2847. Oprava v samostatném skriptu - vyhození paliv která tam nepatří
  2847, # vedle sebe s id 1184. Oprava v samostatném skriptu - vyhození paliv která tam nepatří
  819, # vedle sebe s id 2475
  3606, # měla duplicity 4718 a 4713
  623, # vedle sebe s id 1881
  1881, # vedle sebe s id 623
  1221, # měla duplicitu 4815
  434, # vedle sebe s id 2418
  2418, # vedle sebe s id 434
  125, # vedle sebe s id 2860
  2860, # vedle sebe s id 125
  593, # vedle sebe s id 2888
  2888, # vedle sebe s id 593; oprava jména v samostatném skriptu
  2594, # měla duplicitu id 2060
  3225, # vedle sebe s id 3472; oprava jména v samostatném skriptu
  3472, # vedle sebe s id 3225
  3209, # vedle sebe s id 2957
  548, # měla duplicitu id 1320
  1114, # vedle sebe s id 3277
  3277, # vedle sebe s id 1114
  1842, # měla duplicitu 4727; oprava jména v samostatném skriptu
  1160, # vedle sebe s id 3813
  3813, # vedle sebe s id 1160
  396, # vedle sebe s id 995
  995, # vedle sebe s id 396
  59, # vedle sebe s ids 103, 918 a 4375
  103, # vedle sebe s ids 59, 918 a 4375
  918, # vedle sebe s ids 59, 103 a 4375
  4375, # vedle sebe s ids 59, 103 a 918
  832, # vedle sebe s ids 961 a 2498
  961, # vedle sebe s ids 832 a 2498
  2498, # vedle sebe s ids 832 a 961
  532, # vedle sebe s id 2370
  2370, # vedle sebe s id 532
  169, # vedle sebe s id 2622
  2622, # vedle sebe s id 169
  353, # vedle sebe s id 1486 a 2614
  2614, # vedle sebe s id 353 a 1486
  2040, # měla duplicitu 4586
  56, # vedle sebe s ids 631 a 2543
  631, # vedle sebe s ids 56 a 2543
  2543, # vedle sebe s ids 56 a 631
  290, # vedle sebe s ids 2385 a 3061
  2385, # vedle sebe s ids 290 a 3061
  3061, # vedle sebe s ids 290 a 2385
  146, # měla duplicitu 4561
  978, # vedle sebe s ids 1164 a 4480
  1164, # vedle sebe s ids 978 a 4480
  4480, # vedle sebe s ids 978 a 1164
  311, # vedle sebe s id 2712
  1453, # vedle sebe s id 2189
  969, # měla duplicitu 892
  52, # vedle sebe s id 780
  780, # vedle sebe s id 52
  371, # vedle sebe s ids 900 a 4303
  900, # vedle sebe s ids 371 a 4303
  4303, # vedle sebe s ids 371 a 900
  90, # vedle sebe s id 1145
  1145, # vedle sebe s id 90
  703, # vedle sebe s id 787
  787, # vedle sebe s id 703
  3, # vedle sebe s ids 944 a 2441
  944, # vedle sebe s ids 3 a 2441
  2441, # vedle sebe s ids 3 a 944
  7, # vedle sebe s id 257; oprava jména v samostatném skriptu
  257, # vedle sebe s id 7
  1156, # vedle sebe s id 2371
  2371, # vedle sebe s id 1156
  573, # vedle sebe s id 641
  641, # vedle sebe s id 573
  42, # vedle sebe s id 400
  400, # vedle sebe s id 42
  1443, # vedle sebe s id 1964
  1964, # vedle sebe s id 1443
  2959, # vedle sebe s id 3298
  3298, # vedle sebe s id 2959
  234, # vedle sebe s id 4327
  4327, # vedle sebe s id 234
  770, # měla duplicitu id 769
  706, # vedle sebe s id 3924
  3924, # vedle sebe s id 706
  2535, # vedle sebe s ids 755 a 2403 a také s 986
  986, # vedle sebe s id 2535
  2403, # vedle sebe s ids 755 a 2535; oprava jména v samostatném skriptu
  755, # vedle sebe s ids 2535 a 2403
  722, # vedle sebe s id 4477
  4477, # vedle sebe s id 722; oprava jména v samostatném skriptu
  265, # vedle sebe s id 505
  505, # vedle sebe s id 265
  1335, # vedle sebe s id 1336
  1336, # vedle sebe s id 1335
  2464, # vedle sebe s id 2662
  2662, # vedle sebe s id 2464
  245, # vedle sebe s id 619
  619, # vedle sebe s id 245
  230, # vedle sebe s id 3797
  3797, # vedle sebe s id 230
  88, # vedle sebe s ids 128 a 1693
  128, # vedle sebe s ids 88 a 1693
  1693, # vedle sebe s ids 88 a 128
  36, # vedle sebe s ids 229 a 2797
  229, # vedle sebe s ids 36 a 2797
  2797, # vedle sebe s ids 36 a 229; oprava jména v samostatném skriptu
  1458, # vedle sebe s id 3457
  3457, # vedle sebe s id 1458
  172, # vedle sebe s ids 1366 a 2515
  1366, # vedle sebe s ids 172 a 2515
  2515, # vedle sebe s ids 172 a 1366
  916, # vedle sebe s id 3383
  3383, # vedle sebe s id 916
  289, # vedle sebe s id 414
  414, # vedle sebe s id 289
  127, # vedle sebe s ids 738 a 1969
  738, # vedle sebe s ids 127 a 1969
  1969, # vedle sebe s ids 127 a 738; oprava jména v samostatném skriptu
  3935, # měla duplicitu id 4494
  338, # vedle sebe s id 1515
  1515, # vedle sebe s id 338
  560, # vedle sebe s id 1174
  1174, # vedle sebe s id 560
  1017, # vedle sebe s id 3351
  3351, # vedle sebe s id 1017
  2476, # vedle sebe s id 2737
  2737, # vedle sebe s id 2476
  1349, # vedle sebe s id 3502
  3502, # vedle sebe s id 1349
  1318, # vedle sebe s id 2411
  2411, # vedle sebe s id 1318
  502, # vedle sebe s id 1965
  1965, # vedle sebe s id 502
  300, # vedle sebe s ids 913 a 3183
  913, # vedle sebe s ids 300 a 3183
  3183, # vedle sebe s ids 300 a 913
  448, # vedle sebe s id 4123
  4123, # vedle sebe s id 448; oprava jména v samostatném skriptu
  3593, # měla duplicitu id 3607
  335, # vedle sebe s id 582
  582, # vedle sebe s id 335
  380, # vedle sebe s id 1176
  1176, # vedle sebe s id 380
  165, # vedle sebe s id 2108
  2108, # vedle sebe s id 165; oprava jména v samostatném skriptu
  296, # vedle sebe s id 2678
  2678, # vedle sebe s id 296
  460, # vedle sebe s id 3170; oprava jména v samostatném skriptu
  3170, # vedle sebe s id 460
  2472, # měla duplicitu 975; oprava jména v samostatném skriptu
  205, # vedle sebe s id 3251
  3251, # vedle sebe s id 205
  1171, # vedle sebe s id 1172
  1172, # vedle sebe s id 1171
  1236, # měla duplicitu id 3702
  5, # vedle sebe s id 8
  8, # vedle sebe s id 5
  481, # vedle sebe s id 1506; vyhození cen LPG (patří k id 1506) v samostatném skriptu
  1506, # vedle sebe s id 481
  541, # vedle sebe s ids 747 a 2926
  747, # vedle sebe s ids 541 a 2926
  2826, # vedle sebe s ids 541 a 747
  695, # vedle sebe s id 3631
  3631, # vedle sebe s id 695
  3189, # měla duplicitu id 4826
  1275, # vedle sebe s id 3273
  3273, # vedle sebe s id 1275
  447, # vedle sebe s id 3435
  3435, # vedle sebe s id 447; oprava jména v samostatném skriptu
  523, # vedle sebe s ids 1587 a 4329
  1587, # vedle sebe s ids 523 a 4329
  4329, # vedle sebe s ids 523 a 1587
  2500, # vedle sebe s id 2899; oprava jména v samostatném skriptu
  2899, # vedle sebe s id 2500; jméno neopravím, to město není na streetview :(
  1502, # vedle sebe s ids 2159 a 2673
  2159, # vedle sebe s ids 1502 a 2673; oprava jména v samostatném skriptu
  2673, # vedle sebe s ids 1502 a 2159; oprava jména v samostatném skriptu
  1151, # vedle sebe s id 2512
  2512, # vedle sebe s id 1151
  581, # vedle sebe s id 3308; oprava jména a ceny pro LPG přepsány pro id 3308 v samostatném skriptu
  3308, # vedle sebe s id 581; oprava jména v samostatném skriptu
  1347, # vedle sebe s id 1348
  1348, # vedle sebe s id 1347
  248, # vedle sebe s id 815
  815, # vedle sebe s id 248
  161, # vedle sebe s id 952
  952, # vedle sebe s id 161
  821, # vedle sebe s id 2451
  2451, # vedle sebe s id 821
  333, # vedle sebe s id 407; oprava jména v samostatném skriptu
  407, # vedle sebe s id 333
  58, # vedle sebe s id 2719
  2719, # vedle sebe s id 58
  1397, # vedle sebe s id 2247
  2247, # vedle sebe s id 1397; LPG stanice, nejasné jméno, oprava na name == "lpg" v samostatném skriptu
  43, # vedle sebe s id 571
  571, # vedle sebe s id 43
  436, # vedle sebe s id 441
  441, # vedle sebe s id 436
  476, # vedle sebe s id 486
  486, # vedle sebe s id 476
  423, # vedle sebe s id 2940
  2940, # vedle sebe s id 423
  1428, # vedle sebe s id 2595
  2595, # vedle sebe s id 1428
  401, # vedle sebe s ids 716 a 2588
  716, # vedle sebe s ids 401 a 2588
  2588, # vedle sebe s ids 401 a 716
  431, # vedle sebe s id 2685
  2685, # vedle sebe s id 431
  270, # vedle sebe s id 587
  587, # vedle sebe s id 270
  303, # vedle sebe s id 3991
  3991, # vedle sebe s id 303
  639, # vedle sebe s id 1861
  1861, # vedle sebe s id 639
  911, # vedle sebe s id 912
  912, # vedle sebe s id 911
  2293, # vedle sebe s id 2505
  2505, # vedle sebe s id 2293
  220, # vedle sebe s id 221
  221, # vedle sebe s id 220
  1379, # vedle sebe s id 3295
  3295, # vedle sebe s id 1379
  251, # vedle sebe s id 905
  905, # vedle sebe s id 251
  836, # vedle sebe s id 1409
  1409, # vedle sebe s id 836; měla duplicitu id 2660
  336, # vedle sebe s id 588
  588, # vedle sebe s id 336
  1007, # vedle sebe s id 4231
  4231, # vedle sebe s id 1007
  140, # vedle sebe s id 141
  141, # vedle sebe s id 140
  1196, # vedle sebe s id 1552
  1552, # vedle sebe s id 1196
  437, # vedle sebe s id 455
  455, # vedle sebe s id 437
  1340, # vedle sebe s id 1341
  1341, # vedle sebe s id 1340
  55, # vedle sebe s ids 899 a 4288
  899, # vedle sebe s ids 55 a 4288
  4288, # vedle sebe s ids 55 a 899
  79, # vedle sebe s id 1047
  1047, # vedle sebe s id 79
  2356, # vedle sebe s id 2357
  2357, # vedle sebe s id 2356
  321, # vedle sebe s id 1910
  1910, # vedle sebe s id 321; oprava jména v samostatném skriptu
  349, # vedle sebe s id 1494
  1494, # vedle sebe s id 349; oprava jména v samostatném skriptu
  2089, # měla duplicitu id 3578; oprava jména v samostatném skriptu
  115, # vedle sebe s id 504
  504, # vedle sebe s id 115
  76, # vedle sebe s id 999
  999, # vedle sebe s id 76
  134, # vedle sebe s id 237
  237, # vedle sebe s id 134
  213, # vedle sebe s id 214
  214, # vedle sebe s id 213
  283, # vedle sebe s id 4514
  4514, # vedle sebe s id 283; oprava jména v samostatném skriptu
  355, # vedle sebe s id 2552
  2552, # vedle sebe s id 355
  387, # vedle sebe s id 3975
  3975, # vedle sebe s id 387
  268, # vedle sebe s id 459
  459, # vedle sebe s id 268
  60, # vedle sebe s id 3045
  3045, # vedle sebe s id 60; LPG stanice, nejasné jméno, NA opraveno v samostatném skriptu
  1032, # vedle sebe s id 2736
  2736, # vedle sebe s id 1032
  540, # vedle sebe s id 4522
  4522, # vedle sebe s id 540
  721, # vedle sebe s id 968
  968, # vedle sebe s id 721
  298, # vedle sebe s id 299
  299, # vedle sebe s id 298
  2658, # vedle sebe s id 2724
  2724, # vedle sebe s id 2658
  280, # vedle sebe s id 586
  586, # vedle sebe s id 280
  1415, # měla duplicitu id 4719
  575, # vedle sebe s id 2586
  2586, # vedle sebe s id 575
  451, # vedle sebe s id 1709
  1709, # vedle sebe s id 451
  2820, # měla duplicitu id 2821
  1917, # vedle sebe s id 3228
  3228, # vedle sebe s id 1917
  77, # vedle sebe s id 823; oprava jména v samostatném skriptu
  823, # vedle sebe s id 77
  1179, # vedle sebe s id 2754
  2754, # vedle sebe s id 1179
  1001, # vedle sebe s ids 2549 a 3309
  2549, # vedle sebe s ids 1001 a 3309
  3309, # vedle sebe s ids 1001 a 2549
  1960, # měla duplicitu id 1968
  650, # vedle sebe s id 1278
  1278, # vedle sebe s id 650
  435, # vedle sebe s id 2814
  2814, # vedle sebe s id 435
  2531, # vedle sebe s id 2990; oprava jména v samostatném skriptu
  2990, # vedle sebe s id 2531
  569, # vedle sebe s id 2294; vyhození cen pro LPG (nepatří k benzině) v samostatném skriptu
  2294, # vedle sebe s id 569; oprava jména v samostatném skriptu
  132, # vedle sebe s id 988
  988, # vedle sebe s id 132
  312, # vedle sebe s id 313
  313, # vedle sebe s id 312
  210, # vedle sebe s id 932
  932, # vedle sebe s id 210
  131, # vedle sebe s id 1906
  1906, # vedle sebe s id 131
  102, # vedle sebe s id 2470
  2470, # vedle sebe s id 102
  858, # vedle sebe s id 2823
  2823, # vedle sebe s id 858; oprava jména v samostatném skriptu
  2175, # vedle sebe s id 4053; oprava jména v samostatném skriptu
  4053, # vedle sebe s id 2175
  1831, # vedle sebe s id 2573
  2573, # vedle sebe s id 1831
  420, # vedle sebe s id 1055
  1055, # vedle sebe s id 420
  1600, # vedle sebe s id 3803
  3803, # vedle sebe s id 1600
  514, # vedle sebe s id 929
  929, # vedle sebe s id 514
  648, # vedle sebe s id 4028
  4028, # vedle sebe s id 648; oprava jména v samostatném skriptu
  520, # vedle sebe s id 3584
  3584, # vedle sebe s id 520
  453, # vedle sebe s id 947
  947, # vedle sebe s id 453
  1980, # vedle sebe s id 1981
  1981, # vedle sebe s id 1980
  930, # vedle sebe s id 1525
  1525, # vedle sebe s id 930
  266, # vedle sebe s id 1902
  1902, # vedle sebe s id 266
  1021, # vedle sebe s id 2890
  2890, # vedle sebe s id 1021; ale není vidět na google
  1009, # vedle sebe s id 1049
  1049, # vedle sebe s id 1009
  1741, # vedle sebe s id 2650
  2650, # vedle sebe s id 1741
  1359, # vedle sebe s id 3490
  3490, # vedle sebe s id 1359
  628, # vedle sebe s id 3160
  3160, # vedle sebe s id 628
  2804, # vedle sebe s id 3919
  3919, # vedle sebe s id 2804
  544, # vedle sebe s id 545
  545, # vedle sebe s id 544
  1355, # vedle sebe s id 3040
  3043, # vedle sebe s id 1355
  1954, # vedle sebe s id 2010
  2010, # vedle sebe s id 1954
  443, # vedle sebe s id 1951
  1951, # vedle sebe s id 443
  177, # vedle sebe s id 1547
  1547, # vedle sebe s id 177
  2155, # měla duplicitu id 3937
  1540, # vedle sebe s id 1905
  1905, # vedle sebe s id 1540
  27, # vedle sebe s id 3357; špatně zařazená cena pro LPG, patří k id 3357, oprava v samostatném skriptu
  3357, # vedle sebe s id 27
  784, # vedle sebe s id 2355
  2355, # vedle sebe s id 784
  138, # vedle sebe s id 2480
  2480, # vedle sebe s id 138; oprava jména v samostatném skriptu
  507, # vedle sebe s id 547
  547, # vedle sebe s id 507
  1997, # vedle sebe s id 2209
  2209, # vedle sebe s id 1997; oprava jména v samostatném skriptu
  160, # vedle sebe s id 216
  216, # vedle sebe s id 160; oprava jména v samostatném skriptu
  369, # vedle sebe s id 4368
  4368, # vedle sebe s id 369
  2960, # měla duplicitu id 1787
  2563, # vedle sebe s id 4361
  4361, # vedle sebe s id 2563
  490, # vedle sebe s id 2011
  2011, # vedle sebe s id 490
  92, # vedle sebe s id 1095
  1095, # vedle sebe s id 92
  373, # vedle sebe s id 1054
  1054, # vedle sebe s id 373
  1050, # vedle sebe s id 4710
  4710, # vedle sebe s id 1050
  1941, # měla duplicitu id 4759
  45, # vedle sebe s id 4104
  4104, # vedle sebe s id 45
  227, # vedle sebe s id 277
  277, # vedle sebe s id 227
  1319, # vedle sebe s id 1462
  1462, # vedle sebe s id 1319
  798, # vedle sebe s id 2520
  2520, # vedle sebe s id 798
  2140, # vedle sebe s id 3206
  3206, # vedle sebe s id 2140
  1333, # vedle sebe s id 1334
  1334, # vedle sebe s id 1333
  281, # vedle sebe s id 910
  910, # vedle sebe s id 281
  3444, # vedle sebe s id 4067
  4067, # vedle sebe s id 3444
  1961, # vedle sebe s id 2121
  2121, # vedle sebe s id 1961
  72, # vedle sebe s id 4284
  4284, # vedle sebe s id 72
  966, # vedle sebe s id 1342
  1342, # vedle sebe s id 966
  262, # vedle sebe s id 412
  412, # vedle sebe s id 262
  1642, # vedle sebe s id 1649; ale na google není zaměřená, je to na hranicích s DE
  1649, # vedle sebe s id 1642; ale na google není zaměřená, je to na hranicích s DE
  801, # vedle sebe s id 3380
  3380, # vedle sebe s id 801
  1276, # vedle sebe s id 1957
  1957, # vedle sebe s id 1276
  331, # vedle sebe s id 2688
  2688, # vedle sebe s id 331
  135 # měla duplicitu id 2972
  # --- Magdaléna Šuterová -- červen 2019 -- začátek ---
)





# sjednocení čerpacích stanic -------------------------------------------------------

# seznam id čerpacích stanic, které mají být sjednoceny; seznam obsahuje vektory
# id; id čerpacích stanic v každém atomickém vektoru id se změní na první id
# zadané v tomto vektoru
# TODO: seznam stanic, které mají být sjednoceny se musí doplnit po každém
# seznam id čerpacích stanic, které mají být odstraněny z dat
# target_id ... id základní čerpací stanice, pod kterou se to sjednotí; její
#   hodnoty jsou implicitní, tj. použijí se, pokud je nenahradí připojovaná
#   stanice
# source_id ... id čerpací stanice, která má být sejdnocena s target_id -- její
#   hodnoty části času nahradí / doplní hodnoty target_id; tato stanice se pak
#   vyřadí z dat
# feature ... jaká vlastnost má být nahrazena; "price", "name", "location",
#   "sgs", "nonstop", jejich kombinace (např. "location, sgs, nonstop") nebo
#   "all"
# from, to ... datum od kdy do kdy ve formátu "YYYY-MM-DD"
# keep ... logická; pokud TRUE, pak se v intervalu nechají i hodnoty z target_id
#   (tj. source_id je doplní) a jen se následně odstraní duplicity; pokud FALSE
#   (asi častější), pak se hodnoty z target_id v daném časovém okně odstraní a
#   nahradí hodnotami ze source_id
# skupina komentářů patří vždy k těm stanicím nad nimi; odděluje skupiny stanic,
#   které byly identifikované jako too_close

pumpdroid_stations_to_be_united <- tribble(
  ~ target_id, ~ source_id, ~ feature, ~ from, ~ to, ~ keep,

  #diagnose(stations_too_close[[1]])
  1073, 1477, "price, location, sgs, nonstop", "start", "end", FALSE,
  1073, 3723, "all", "start", "end", FALSE,
  # 1477 name == tomegas, ale to je jen dodavatel LPG paliva, jak to chápu. Nechávám slovnaft z předchozího.

  #diagnose(stations_too_close[[2]])
  1655, 1479, "price", "start", "end", FALSE,
  1655, 2466, "price, location, sgs, nonstop", "start", "end", FALSE,
  1655, 2466, "all", "2014-09-22", "end", FALSE,
  1655, 3842, "all", "start", "end", FALSE,
  # 1655 dává jméno Calibra plus. Pro id 2466 jsou tam až do 2014-09-21 zavedená divná jména, která google nezná (nova-kont), anebo NA. 2466 divné značky až do 2014-09-21, potom značka Zaris, která už je googlu známá

  #diagnose(stations_too_close[[4]])
  709, 3315, "all", "start", "end", FALSE,
  1253, 1459, "price", "start", "end", FALSE,
  1253, 3293, "price, location, sgs, nonstop", "start", "end", FALSE,
  # 709 je v datech až do 2012-12-05 Eurooil, od 2012-12-06 Eurobit. Dle všeho ale byla Eurooil celou dobu, protože Eurobit je ta, co je naproti přes ulici, id 1253. Oprava jména v samostatném skriptu. 1253 ok, delta oil, pak změna na eurobit. 1459 jen doplňuje část dat pro LPG pro id 1253.

  #diagnose(stations_too_close[[5]])
  121, 3811, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[6]])
  181, 2005, "price", "start", "end", FALSE,
  # 181 celou dobu ok. 2005 má cenu CNG, doplnění k id 181 v samostatném skriptu

  #diagnose(stations_too_close[[9]])
  3358, 4410, "all", "start", "end", TRUE,
  # bez problému

  #diagnose(stations_too_close[[10]])
  1808, 4705, "all", "2018-12-08", "end", TRUE,
  # bez problému

  #diagnose(stations_too_close[[11]])
  1522, 4099, "all", "start", "end", TRUE,
  # to vlastnictví je ale nejasné, podle fotek na Google maps to Eurooil nikdy nebyl. oprava v samostatném skriptu

  #diagnose(stations_too_close[[12]])
  1045, 3624, "all", "start", "end", TRUE,
  1045, 4289, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[13]])
  1442, 3321, "price, location, sgs, nonstop", "start", "end", FALSE,
  # 1442 je CNG a LPG stanice, v PumpDroid divná jména. V Google jméno Kralupol z 6/2017, starší fotky v google nejsou. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[14]])
  3278, 4068, "all", "start", "end", TRUE,
  # jméno by asi celou dobu mělo být něco jako čerpací stanice Kvasice, nevypadá to, že by se nějak měnili majitelé. Ale na Google fotky z 8/2011 takže to není a asi nebude úplně jasné. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[15]])
  723, 3343, "all", "2013-03-14", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[16]])
  2841, 3722, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[17]])
  3198, 3950, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[18]])
  3602, 3765, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[19]])
  3568, 3703, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[20]])
  3035, 3174, "all", "2012-08-18", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[21]])
  1652, 4263, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[22]])
  2517, 4573, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[23]])
  3009, 2092, "all", "start", "end", TRUE,
  #  2092 jen nahradí ceny LPG

  #diagnose(stations_too_close[[24]])
  956, 4819, "all", "2018-11-13", "end", FALSE,
  # 956 omv, později benzina

  #diagnose(stations_too_close[[25]])
  2536, 3846, "price, location, sgs, nonstop", "start", "end", FALSE,
  # má být jméno Benz celou dobu

  #diagnose(stations_too_close[[27]])
  1360, 4209, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[28]])
  2378, 4550, "all", "2017-06-15", "end", FALSE,
  2378, 4635, "all", "2018-06-07", "end", FALSE,
  2378, 2911, "price", "start", "end", FALSE,
  # avanti, později benzina. Pro část dat mezi 2018-06-07 a 2017-12-25 je name == NA, ale má být Benzina podle fotek na Google; červen 2017 je tam Benzina. Id 2911 je jen LPG

  #diagnose(stations_too_close[[29]])
  869, 3003, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[30]])
  1702, 3825, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[32]])
  2099, 3609, "all", "start", "end", FALSE,
  2099, 4468, "all", "2017-03-18", "end", FALSE,
  # LPG stanice vedle dalších dvou benzinek, ids 31 a 1919. V téhle LPG i dvě ceny pro diesel které tam nemají co dělat - vyhodit.

  #diagnose(stations_too_close[[33]])
  4089, 3093, "price, location, sgs, nonstop", "start", "end", FALSE,
  # celou dobu má být name == dopa

  #diagnose(stations_too_close[[36]])
  99, 4073, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[37]])
  2468, 2325, "all", "start", "2012-02-26", FALSE,
  2468, 2173, "price, location, sgs, nonstop", "start", "2012-03-29", FALSE,
  # bez problému

  #diagnose(stations_too_close[[38]])
  3303, 1818, "all", "start", "end", FALSE,
  # mělo by být name == petr celou dobu

  #diagnose(stations_too_close[[39]])
  3005, 4287, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[40]])
  2291, 3384, "all", "start", "end", FALSE,
  2291, 4367, "all", "start", "end", FALSE,
  2291, 4526, "all", "start", "end", FALSE,
  # 2291 by měla mít jméno agw, změny jména ok, odpovídají Googlu

  #diagnose(stations_too_close[[41]])
  1592, 3264, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[42]])
  3986, 3621, "price, location, sgs, nonstop", "start", "2012-03-29", FALSE,
  # mělo by být name == eryx celou dobu

  #diagnose(stations_too_close[[44]])
  2467, 3185, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[45]])
  2326, 4056, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[47]])
  3345, 4291, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[48]])
  1485, 2023, "all", "start", "end", TRUE,
  1485, 3498, "all", "start", "2016-12-03", TRUE,
  1485, 3498, "price, location, sgs, nonstop", "2016-12-04", "2017-03-14", TRUE,
  1485, 3498, "all", "2017-03-15", "end", FALSE,
  # v intervalu ("2016-12-04", "2017-03-14") je name == v rekonstrukci, má být asi arcos

  #diagnose(stations_too_close[[50]])
  1242, 2309, "price, location, sgs, nonstop", "start", "end", FALSE,
  # tohle je dost nejasné, jestli to tam patří nebo ne. V řádku 50 jsou tři stanice, z nichž 2309 je jen LPG. Ty další dvě mají obě zaznamenané nějaké ceny pro LPG, kdy 1242 jen tři pozorování. Na Google není nikde cedule LPG vidět. Buďto lepší, když budou biased obě, a pak tohle sjednocení platí, nebo žádná, ale to pak nevím, proč by tam ty ceny pro LPG vůbec byly.

  #diagnose(stations_too_close[[51]])
  1573, 2120, "price, location, sgs, nonstop", "2013-05-20", "end", FALSE,
  # mělo by být name == automania celou dobu

  #diagnose(stations_too_close[[52]])
  1882, 3483, "all", "start", "end", FALSE,
  1882, 4506, "all", "2017-03-15", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[54]])
  2581, 3732, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[56]])
  123, 1537, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[57]])
  2311, 3054, "all", "start", "end", FALSE,
  2311, 4354, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[58]])
  891, 4644, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[59]])
  2809, 4132, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[60]])
  4559, 3350, "price, location, sgs, nonstop", "start", "end", FALSE,
  # mělo by být name == phm vysočina celou dobu

  #diagnose(stations_too_close[[62]])
  1229, 4463, "all", "start", "end", FALSE,
  # bez problému, jen pro část dat id 4463 v intervalu (2016-11-13, 2017-02-19) je name == NA. V tu dobu tam mělo být "tank ono", podle toho jak je z prosince 2016 fotka od uživatele na google.

  #diagnose(stations_too_close[[63]])
  2070, 3719, "all", "start", "end", FALSE,
  # bez problému, ale není jasné vlastnictví. Na Google je nejnovější fotka z r. 2011, kde byla značka "Šmída". Aktuálně je značená jako "soukromá čerpací stanice Vracov". Asi celou dobu soukromá stanice, ne řetězec

  #diagnose(stations_too_close[[64]])
  2073, 4020, "all", "start", "end", FALSE,
  # sjednocení ok, ale jméno špatně. Už u 2073 je zavedeno Eurooil, ale ten to podle Google nikdy neměl. od 2012 až doteď tam je značka Čepro. Manakov v předchozím období sedí. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[65]])
  1885, 4530, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[66]])
  1317, 3337, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[67]])
  3095, 4071, "all", "start", "end", FALSE,
  # jméno špatně, mělo by být tank+tir celou dobu. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[68]])
  1508, 3071, "all", "start", "end", FALSE,
  # jen LPG stanice

  #diagnose(stations_too_close[[71]])
  2521, 4423, "all", "start", "end", FALSE,
  # jméno špatně, mělo by být "čerpací stanice na cihelně" celou dobu. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[72]])
  2508, 4281, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[73]])
  1783, 4606, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[74]])
  3236, 4723, "price, location, sgs, nonstop", "2016-04-04", "end", FALSE,
  # má být name == "bexon", ne miroslav müller i v době date > 2018-04-08. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[75]])
  2591, 3858, "all", "start", "end", FALSE,
  # celou dobu má být name == bemi oil. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[76]])
  2136, 3437, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[77]])
  3285, 3857, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[78]])
  2235, 4412, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[80]])
  2101, 3006, "all", "start", "end", FALSE,
  2101, 4080, "all", "start", "end", FALSE,
  # bez problému, ale je to dost divné pozorování, ty ceny v postatě stojí celou dobu. Navíc jsou data za každý den. Působí to, jako kdyby si to tam ta stanice doplňovala sama.

  #diagnose(stations_too_close[[81]])
  1873, 3711, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[82]])
  1277, 4743, "all", "2017-09-21", "end", TRUE,
  # bez problému; ceny u id 1277 končí různě pro různá paliva, proto TRUE

  #diagnose(stations_too_close[[83]])
  2119, 3098, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[88]])
  1419, 3656, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[89]])
  1841, 4577, "all", "start", "end", FALSE,
  # jméno u id 4577 má být prim. Oprava v samostatném skriptum

  #diagnose(stations_too_close[[92]])
  1804, 3861, "all", "start", "end", FALSE,
  # jméno u id 1804 má být B2oil. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[93]])
  3088, 4321, "all", "start", "end", FALSE,
  # vlastnictví se (asi) neměnilo; část dat s name == NA opravena v samostatném skriptu

  #diagnose(stations_too_close[[94]])
  962, 4628, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[97]])
  3622, 3973, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[99]])
  4223, 2394, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[101]])
  4017, 4051, "all", "start", "end", FALSE,
  4017, 4504, "all", "start", "end", FALSE,
  # v intervalu (2015-02-15, 2015-05-15) je name == NA. Má být celou dobu "m 2000 produkt". Oprava v samostatném skriptu

  #diagnose(stations_too_close[[103]])
  1337, 3772, "all", "start", "end", FALSE,
  # tady jsou v realitě dvě naproti sobě, ale v PumpDroid jsou zadané jako jedna. Dle všeho to vždycky obojí býval Agip, a pak to obojí najednou koupil Mol, takže konkurence se nezměnila. Dost možná byly ty ceny úplně stejné, vzhledem k tomu že je to stejná značka

  #diagnose(stations_too_close[[104]])
  959, 4623, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[108]])
  1874, 3793, "all", "start", "end", FALSE,
  # bez problému, jen špatně jméno pro 1874. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[109]])
  2453, 1516, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[110]])
  1729, 3480, "all", "start", "end", FALSE,
  # jméno celou dobu Diskont tank. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[111]])
  1069, 4554, "name", "start", "end", FALSE,
  1069, 4554, "price, location, sgs, nonstop", "2017-11-03", "end", TRUE,
  # bez problému; změna majitele, ale ceny lépe zaznamenané v 1069

  #diagnose(stations_too_close[[112]])
  20, 3342, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[113]])
  1877, 3125, "all", "start", "2013-12-31", FALSE,
  # bez problému, jen se měnil majitel, což není v PumpDroid zaznamenané. Nejpozději v červnu 2016 už bylo nové jméno, podle fotek Google. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[116]])
  2156, 4139, "all", "start", "end", FALSE,
  # bez problému, jen jméno je zadané jako "lpg" ale podle google to nějaké jméno má. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[117]])
  3438, 4379, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[118]])
  2301, 4511, "all", "start", "end", FALSE,
  2301, 4752, "all", "start", "end", FALSE,
  # bez problému, jen u id 2301 je name == NA. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[120]])
  1988, 3676, "all", "start", "end", FALSE,
  # původně plnící stanice CNG, potom to koupila Benzina. Jméno "vps vítkovice" je špatně. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[121]])
  2842, 4652, "price, location, sgs, nonstop", "start", "end", FALSE,
  # ceny 2842 v r. 2013 jsou dost divné, zejména ve srovnání se sousední LPG stanicí id 1474

  #diagnose(stations_too_close[[122]])
  # tady je potřeba vybrat data pro LPG z id 183, protože tam nepatří, a přidat je do id 4004, což je LPG stanice. Dělá to 26. řádek v samostatném skriptu. Přepsáním id by měly být ceny za LPG sjednocené.

  #diagnose(stations_too_close[[123]])
  1809, 3016, "price, location, sgs, nonstop", "start", "end", TRUE,
  # bez problému

  #diagnose(stations_too_close[[125]])
  4571, 4660, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[126]])
  3070, 1589, "price, location, sgs, nonstop", "start", "2012-09-02", FALSE,
  # bez problému

  #diagnose(stations_too_close[[127]])
  1233, 4653, "all", "2017-11-04", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[128]])
  617, 3577, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[131]])
  1684, 4459, "all", "start", "end", FALSE,
  # špatně jméno pro 1684. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[132]])
  1875, 3585, "all", "start", "end", FALSE,
  # jméno nesedí. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[133]])
  2300, 3680, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[135]])
  1586, 2612, "price, location, sgs, nonstop", "start", "end", FALSE,
  1586, 4021, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[136]])
  2816, 3233, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[137]])
  2143, 4184, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[139]])
  2281, 4373, "all", "start", "end", FALSE,
  # jméno nesedí. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[140]])
  2272, 3339, "all", "start", "end", FALSE,
  # jméno nesedí. Oprava v samostatném skriptu

  # TODO: malá LPG pumpa zatím vyhozena
  #diagnose(stations_too_close[[142]])
  # 2972, 2972, "name, location, sgs, nonstop", "start", "end", FALSE,
  # promíchané stanice shell a lpg&cng stanice co je vedle té shell. Id 2972 (lpg) nedává víc info, než kolik je v id 135 (shell) pro ceny lpg&cng. Dávám do vyhozených stanic, takže se id 2972 uvolní. Oprava v samostatném skriptu - data pro ceny lpg&cng mají přiřazeno id 2972, tj. tohle id se znovu obsadí daty z id 135. Jména jsou dobře

  #diagnose(stations_too_close[[143]])
  2212, 4253, "all", "start", "end", FALSE,
  # name == NA pro začátek období u id 2212. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[144]])
  2014, 3476, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[145]])
  4523, 2129, "price, location, sgs, nonstop", "start", "2017-02-27", FALSE,
  # bez problému

  #diagnose(stations_too_close[[146]])
  1904, 4575, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[149]])
  133, 4677, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[150]])
  1680, 4369, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[153]])
  2902, 3947, "all", "start", "end", FALSE,
  # špatně jméno, oprava v samostatném skriptu

  #diagnose(stations_too_close[[155]])
  3699, 601, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  # TODO: malá LPG pumpa zatím vyhozena
  #diagnose(stations_too_close[[156]])
  # 1483, 1483, "name, location, sgs, nonstop", "start", "end", FALSE,
  # zaznamenaná cena LPG u id 1072 patří k id 1483. Podobná situace jako u řádku 142 výše. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[162]])
  2245, 3422, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[163]])
  4235, 2665, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[165]])
  2611, 3161, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[167]])
  936, 4551, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[168]])
  3226, 2511, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[170]])
  # promíchané ceny různých paliv pro normální stanici a pro stanici LPG. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[171]])
  2475, 2930, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[176]])
  1657, 4117, "all", "start", "end", FALSE,
  # name == unknown pro date == 2015-05-21. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[180]])
  3219, 4265, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[182]])
  2957, 1546, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[183]])
  4118, 2433, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[186]])
  2533, 4821, "all", "2016-09-30", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[191]])
  1659, 4113, "all", "start", "end", FALSE,
  # name == NA pro date == 2015-05-15. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[192]])
  2080, 3579, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[193]])
  2757, 3918, "all", "start", "end", FALSE,
  # špatně jméno pro date == 2012-05-12. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[195]])
  1615, 3923, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[197]])
  1430, 4086, "all", "start", "end", FALSE,
  # špatně jména. Oprava v samostatném skriptu

  #diagnose(stations_too_close[[199]])
  1486, 1514, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[200]])
  # ceny pro diesel a natural95 špatně uvedeny i u LPG stanice. Oprava s samostatném skriptu

  #diagnose(stations_too_close[[206]])
  2896, 4657, "all", "start", "end", FALSE,
  # u id 2896 jsou zavedené ceny i pro diesel a N95, což je špatně protože je to jen LPG stanice. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[207]])
  1245, 3439, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  # TODO: malá LPG pumpa zatím vyhozena
  #diagnose(stations_too_close[[209]])
  # 2189, 2189, "name, location, sgs, nonstop", "start", "end", FALSE,
  # u dat pro shell id 1453 jsou zavedeny ceny LPG které patří k hunsgas id 2189. V samostatném skriptu id cen LPG přepsáno z 1453 na 2189. Zároveň tady vyhozena stanice 2189 protože má méně pozorování než LPG které je chybně zadané u id 1453.

  #diagnose(stations_too_close[[214]])
  1332, 4751, "all", "2018-06-17", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[215]])
  2200, 3471, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[217]])
  3051, 4455, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[220]])
  3250, 3899, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[221]])
  2605, 3827, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[223]])
  3564, 3681, "price, location, sgs, nonstop", "start", "end", FALSE,
  # oprava jména v samostatném skriptu

  #diagnose(stations_too_close[[225]])
  2954, 4155, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[228]])
  3633, 4185, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[230]])
  1712, 4119, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[238]])
  2913, 1519, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[256]])
  2708, 4200, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[257]])
  242, 2109, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[260]])
  534, 3741, "all", "start", "end", TRUE,
  # 534 má špatně přiřazené LPG; mělo by být u id 3741. Data pro LPG se přiom překrývají. V tomto skriptu se sjednotí pod id 534 a odstraní se duplicity. V samostatném skriptu se pak k ceně pro LPG přiřadí id 3741, které tento skript zahazuje. Jméno zůstává stejné

  #diagnose(stations_too_close[[262]])
  2723, 3494, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[265]])
  2730, 3912, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[269]])
  2008, 3724, "all", "start", "end", FALSE,
  # jméno špatně. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[270]])
  2454, 3932, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[281]])
  2352, 3911, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[285]])
  2850, 3543, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[291]])
  2674, 3338, "price, location, sgs, nonstop", "start", "end", FALSE,
  # jméno špatně. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[305]])
  2295, 2578, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[306]])
  2308, 4359, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[308]])
  2196, 2829, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[312]])
  2920, 3865, "all", "start", "end", FALSE,
  # u id 2920 je name == NA pro date == 2012-06-09. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[323]])
  1581, 2576, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[343]])
  2838, 4076, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[351]])
  2568, 3092, "price, location, sgs, nonstop", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[352]])
  2273, 3158, "price, location, sgs, nonstop", "start", "end", FALSE,
  # zmatené jméno. Oprava v samostatném skriptu podle údajů z google

  #diagnose(stations_too_close[[354]])
  3204, 4060, "price, location, sgs, nonstop", "start", "end", FALSE,
  # zmatené jméno. Oprava v samostatném skriptu.

  #diagnose(stations_too_close[[382]])
  2507, 3152, "all", "start", "end", FALSE,
  # bez problému

  #diagnose(stations_too_close[[399]])
  2086, 4426, "all", "start", "end", FALSE
  # pro id 2086 je name == NA. Oprava v samostatném skriptu na lpg
)


# konverze vektorů
pumpdroid_stations_close_ok <- as.integer(pumpdroid_stations_close_ok)
pumpdroid_stations_to_be_removed <- as.integer(pumpdroid_stations_to_be_removed)


# konverze sloupců tabulky pumpdroid_stations_to_be_united
pumpdroid_stations_to_be_united <- pumpdroid_stations_to_be_united %>%
  mutate(target_id = as.integer(target_id),
         source_id = as.integer(source_id),
         from = dplyr::if_else(from == "start", start_date, from),
         to = dplyr::if_else(to == "end", end_date, to),
         from = as.Date(from),
         to = as.Date(to),
         keep = as.logical(keep))





# ruční opravy jmen čerpacích stanic ------------------------------------------------

# TODO: opravit start/end -- liší se v jednotlivých částech tabulky!
# TODO: pro velké značky zkontrolovat konec
# TODO: pro velké značky aktualizovat
pumpdroid_station_names_correction <- tibble::tribble(
    ~id, ~from, ~to, ~name,
    # náhodně nalezené opravy -- Magdaléna Šuterová -- start
    709, "start", "end", "eurooil",
    1522, "start", "end", "kelčice",
    1442, "start", "end", "kralupol",
    3278, "start", "end", "kvasice",
    2073, "start", "end", "eurooil",
    3095, "start", "end", "tank + tir",
    2521, "start", "end", "na cihelně",
    3236, "start", "2013-11-25", "cg 01",
    2591, "start", "end", "bemi oil",
    2559, "start", "end", "amodo",
    1841, "2017-06-15", "end", "prim",
    1804, "2013-10-14", "2013-10-14", "b2oil", # jen pro jedno datum
    3088, "start", "end", "vena trade",
    4017, "start", "end", "m 2000 produkt",
    4516, "start", "end", "lpg pardubice",
    2872, "start", "end", "as plus",
    2702, "start", "end", "eurobit",
    1874, "2012-05-12", "2014-08-10", "městská čerpací stanice",
    1729, "2011-08-01", "end", "diskont tank",
    1877, "2014-04-12", "end", "K&P čerpací stanice",
    2156, "start", "end", "daf service",
    2301, "2012-05-12", "2015-11-20", "kumegas",
    2244, "start", "end", "bk soft",
    1875, "2012-05-12", "2013-11-25", "cg-04",
    1875, "2014-01-22", "end", "kokonín",
    2281, "start", "end", "rikro",
    2272, "start", "end", "u krobiána",
    2212, "start", "end", "wloch",
    4442, "start", "end", "dopravní podnik hl.m. prahy",
    2330, "2012-05-12", "2012-07-29", "k petrol",
    2901, "start", "end", "stafiko",
    4117, "start", "2015-05-21", "calibra plus",
    2888, "2012-05-20", "2012-06-09", "tomegas",
    3225, "2012-11-06", "2015-03-15", "flaga",
    1842, "start", "end", "arex",
    1659, "start", "end", "zaris",
    2757, "start", "end", "davo oil",
    1430, "2012-05-12", "2012-05-12", "esoil", # jen pro jedno datum
    1430, "2015-05-10", "2015-05-15", "dmv holding",
    2040, "2014-02-22", "2014-05-05", "plyn",
    3564, "2013-10-14", "end", "psota",
    2403, "2012-05-12", "2012-10-07", "expres24",
    # station_names[station_names$id == 2403 & station_names$date == "2012-10-07",] <- filter(station_names, id == 2403 & date == "2012-10-07") %>% mutate(date = "2017-09-01")
    # Tento předcházející byl podle google fotek v r. 2012 ještě pořád expres24, v PD ale vedeno jako benzina. Ta to vlastnila až později. Teď neřešit, vyřeším v dalším kroku, kde budu kontrolovat velké značky.
    4477, "start", "end", "lpg u jeepa",
    2797, "start", "end", "spolgas",
    4123, "start", "end", "linde gas",
    2108, "2012-05-12", "2016-06-24", "flaga",
    460, "2012-05-12", "2012-12-15", "orlen",
    2008, "2012-05-12", "2014-07-02", "švestka cng",
    3435, "2013-05-20", "2013-08-03", "mc-sar",
    2673, "2012-05-12", "2012-08-11", "u celnice",
    3308, "2012-05-12", "2013-01-19", "grizzly gas",
    3308, "2015-01-25", "2015-01-31", "kubojama",
    333, "2012-11-06", "2013-04-29", "orlen",
    2247, "start", "end", NA,  # bylo "lpg"
    2920, "2012-06-09", "2013-07-15", "ax oil",
    1910, "start", "end", "koloc oil",
    1494, "start", "end", "tomegas",
    2089, "start", "end", "lpg horák",
    4514, "start", "end", "flaga",
    2273, "start", "end", "benč",
    3204, "start", "end", "rapid oil",
    2531, "start", "end", "as",
    2294, "start", "end", "tomegas",
    2823, "start", "end", "hošek",
    2175, "start", "end", "schnell",
    4028, "start", "end", "strakoil",
    2480, "start", "end", "pieran",
    2209, "start", "end", "henig",
    2086, "start", "end", NA,  # bylo "lpg"
    216, "2017-04-17", "end", "maroli",
    1988, "2014-03-09", "end", "benzina",
    1684, "start", "2015-04-06", "q group",
    7, "2015-12-27", "end", "mol",
    1969, "start", "2017-08-20", "avanti",
    2472, "start", "end", "omv",
    2500, "start", "end", "koloc oil",
    2159, "start", "2014-01-22", "avanti",
    581, "start", "end", "benzina",
    77, "2015-08-09", "end", "mol",
    # náhodně nalezené opravy -- Magdaléna Šuterová -- stop
    # opravy na základě dat Molu (pro duben 2018) -- Magdaléna Šuterová -- start
    1071, "2017-02-01", "end", "papoil",
    1074, "2018-08-01", "end", "papoil",
    1077, "2017-03-01", "end", "papoil",
    1082, "2019-01-01", "end", "papoil",
    1086, "2017-05-01", "end", "papoil",
    1180, "2018-07-01", "end", "mol",
    1183, "2018-12-01", "end", "mol",
    1184, "2019-07-01", "end", "mol",
    1186, "2019-07-01", "end", "mol",
    1192, "2018-09-01", "end", "mol",
    1193, "2018-09-01", "end", "mol",
    1195, "2019-07-01", "end", "mol",
    1197, "2019-01-01", "end", "mol",
    1221, "2019-01-01", "end", "mol",
    1225, "2018-12-01", "end", "mol",
    1232, "2014-07-01", "end", "papoil",
    1237, "2012-04-01", "end", "papoil",
    1240, "2017-03-01", "end", "mol",
    1244, "2019-04-01", "end", "mol",
    1252, "2017-06-01", "end", "mol",
    1256, "2019-10-01", "end", "mol",
    1263, "2018-02-01", "end", "mol",
    1266, "2018-02-01", "end", "mol",
    1267, "2018-11-01", "end", "mol",
    1269, "2019-02-01", "end", "mol",
    1273, "2018-06-01", "end", "mol",
    1294, "2019-02-01", "end", "mol",
    1296, "2019-04-01", "end", "mol",
    2379, "2019-05-01", "end", "mol",
    2443, "2018-09-01", "end", "mol",
    2479, "2014-07-01", "end", "slovnaft",
    2539, "2018-02-01", "end", "mol",
    1721, "2013-01-12", "end", "technické služby města olomouce",
    2841, "2011-08-01", "end", "honem",
    # opravy na základě dat OMV (pro duben 2018) -- Magdaléna Šuterová -- start
    # opravy na základě dat OMV (pro duben 2018) -- Magdaléna Šuterová -- stop
    # opravy na základě dat CCS pro Benzinu (konec roku 2018) -- Magdaléna Šuterová -- start
    400, "2018-08-01", "end", "benzina",
    918, "2018-08-01", "end", "benzina",
    576, "2017-03-01", "end", "benzina",
    1969, "2018-02-01", "end", "benzina",
    988, "2017-12-01", "end", "benzina",
    1971, "2018-05-01", "end", "benzina",
    274, "2018-08-01", "end", "benzina",
    464, "2016-04-01", "end", "benzina",
    528, "2011-09-01", "end", "benzina",
    550, "2009-10-01", "end", "benzina",
    335, "2012-03-01", "end", "benzina",
    2378, "2017-06-01", "end", "benzina",
    574, "2011-08-01", "end", "benzina",
    281, "2017-04-01", "end", "benzina",
    503, "2011-10-01", "end", "benzina",
    518, "2011-07-01", "end", "benzina",
    373, "2011-07-01", "end", "benzina",
    978, "2018-06-01", "end", "benzina",
    351, "2012-04-01", "end", "benzina",
    470, "2011-06-01", "end", "benzina",
    1419, "2009-05-01", "end", "benzina",
    278, "2009-06-01", "end", "benzina",
    492, "2018-01-01", "end", "benzina",
    956, "2018-12-01", "end", "benzina",
    353, "2012-03-01", "end", "benzina",
    451, "2011-10-01", "end", "benzina",
    525, "2012-03-01", "end", "benzina",
    279, "2012-04-01", "end", "benzina",
    2357, "2018-09-01", "end", "benzina",
    431, "2018-04-01", "end", "benzina",
    423, "2009-07-01", "end", "benzina",
    564, "2011-09-01", "end", "benzina",
    575, "2011-07-01", "end", "benzina",
    3183, "2009-06-01", "end", "benzina",
    434, "2011-09-01", "end", "benzina",
    534, "2011-07-01", "end", "benzina",
    3988, "2011-08-01", "end", "benzina",
    1028, "2009-09-01", "end", "omv",
    2453, "2012-04-01", "end", "neptun-harfa",
    # opravy na základě dat CCS pro Benzinu (konec roku 2018) -- Magdaléna Šuterová -- stop
    2049, "2018-07-01", "end", "shell",
    90, "2017-12-01", "end", "omv",
    145, "2019-05-01", "end", "omv",
    997, "2018-01-01", "end", "benzina",
    1041, "2018-09-01", "end", "free 1",
    1439, "2018-11-01", "end", "omv",
    2370, "2017-06-01", "end", "omv",
    2719, "2011-10-01", "end", "omv",
    2768, "2018-10-01", "end", "omv",
    3367, "2011-08-01", "end", "omv",
    # další náhodně nalezené opravy -- Michal Kvasnička -- start
    56, "2013-01-01", "2015-07-31", "agip",
    56, "2015-08-01", "2018-12-31", "mol"
    # další náhodně nalezené opravy -- Michal Kvasnička -- stop
    # opravy velkých značek -- podle značek -- Michal Kvasnička -- start
    # 133, "2017-10-01", "end", "eurobit",
    # 135, "2012-05-12", "end", "shell",
    # 451, "2000-01-01", "end", "benzina",
    # 494, "2000-01-01", "end", "benzina",
    # 513, "2000-01-01", "end", "benzina",
    # 522, "2013-04-21", "end", "kelcice",
    # 537, "2000-01-01", "end", "benzina",
    # 838, "2017-11-01", "end", "robin oil",
    # 862, "2017-04-01", "end", "libečkov",
    # 909, "2017-11-01", "end", "free 1",
    # 923, "2017-11-01", "end", "benzina",
    # 958, "2017-11-01", "end", "benzina",
    # 1021, "2017-11-01", "end", "benzina",
    # 1041, "2017-10-01", "end", "free 1",
    # 1069, "2012-06-01", "end", "mol",
    # 1261, "2017-11-01", "end", "benzina",
    # 1394, "2016-10-01", "end", "mol",
    # 1419, "2017-01-01", "end", "prospeed",
    # 1465, "2017-11-01", "end", NA,
    # 1537, "2012-11-06", "end", NA,
    # 1642, "2012-01-01", "end", "free 1",
    # 1644, "2012-01-01", "end", "free 1",
    # 1781, "2012-05-12", "end", "cermak",
    # 1786, "2012-05-12", "end", "rabštejn",
    # 1971, "2017-11-01", "end", "benzina",
    # 2073, "2012-05-27", "end", "warman mnišek",
    # 2373, "2016-11-01", "end", "prim",
    # 2379, "2017-06-01", "end", "papoil",
    # 2479, "2017-06-01", "end", "mol",
    # 2517, "2017-03-01", "end", "benzina",
    # 2544, "2016-08-01", "end", "prim",
    # 2621, "2017-11-01", "end", "eurooil",
    # 2623, "2012-06-01", "end", "pletka",
    # 2674, "2012-05-12", "end", "moravia-bagr",
    # 2747, "2017-11-01", "end", "eurooil",
    # 2782, "2017-10-01", "end", "free 1",
    # 2841, "2017-11-01", "end", "honem",
    # 2868, "2016-08-01", "end", "prim",
    # 2909, "2013-09-04", "end", NA,
    # 2963, "2016-11-01", "end", "prim",
    # 2976, "2014-12-30", "end", "dřeveš",
    # 3403, "2017-11-01", "end", "eurooil",
    # 3445, "2014-01-22", "end", "votava",
    # 3497, "2016-08-01", "end", "prim",
    # 3545, "2016-09-01", "end", "prim",
    # 3647, "2014-02-15", "end", "ipari park",
    # 3662, "2017-10-01", "end", "free 1",
    # 3742, "2014-07-02", "end", "pavel cervenka",
    # 3870, "2017-11-01", "end", "vena trade",
    # 3913, "2012-01-01", "end", "free 1"
    # opravy velkých značek -- podle značek -- Michal Kvasnička -- stop
)

pumpdroid_station_names_correction <- pumpdroid_station_names_correction %>%
  mutate(id = as.integer(id),
         from = dplyr::if_else(from == "start", start_date, from),
         to = dplyr::if_else(to == "end", end_date, to),
         # to = dplyr::if_else(to == "?", from, to),  # TODO: ověřit!!!
         from = as.Date(from),
         to = as.Date(to)) %>%
  normalize_pumpdroid_names() %>%
  unify_pumpdroid_station_names(pumpdroid_station_names_to_be_unified) %>%
  remove_pumpdroid_generic_names()





# brute force brand names correction ------------------------------------------------

# This table can be used to correct brand names after big takeovers. It assumes
# that there is some terminal date (possibly more than one terminal dates) when
# all names for a brand are already correct after a takeover. It also assumes
# that we know the precise date of the takeovers. If so, we can detect all
# stations that were taken over and impose the correct date.
#
# Why the takeover may be seen in Pumpdroid data too late: It is because it
# takes some time before the station is physically repainted, and citizens can
# change the brand name usually only when they can see the station colors
# changed.

# correction table must have the following columns:
# 1. takeover date (Date) ... the date when source station was taken over by
#    target station
# 2. terminal_date (Date) ... the date when
# 3. source (character) ... the code name of the station that was taken over by
#    target
# 4. target (character) ... the code name of the station that taken over the
#    source
takeovers_brute_force_correction_table <- tribble(
  ~takeover_date, ~terminal_date, ~source, ~target,
  "2000-01-01", "2018-12-31", "orlen", "benzina",
  "2000-01-01", "2018-12-31", "star", "benzina",
  "2012-01-01", "2018-12-31", "slovnaft", "mol",  # the takeover was earlier
  "2012-07-01", "2018-12-31", "papoil", "mol",
  "2014-08-01", "2018-12-31", "lukoil", "mol",
  "2015-08-01", "2018-12-31", "agip", "mol",
  "2016-02-01", "2018-12-31", "omv", "benzina",
  "2016-02-01", "2018-12-31", "avanti", "benzina"
) %>%
  mutate_at(c("takeover_date", "terminal_date"), as.Date)





# testy integrity -------------------------------------------------------------------

# testovací funkce
no_of_errors <- 0
check <- function(test, message, detail = NULL) {
  if (!test) {
    cat("Problem:", message, "!\n")
    if (!is.null(detail))
      cat("Detail: id(s)", detail, "\n\n")
    no_of_errors <<- no_of_errors + 1
  }
}

# testy: pumpdroid_stations_close_ok, pumpdroid_stations_to_be_removed a pumpdroid_stations_to_be_united

# - v tabulkách nejsou duplicity
check(length(pumpdroid_stations_close_ok) == length(unique(pumpdroid_stations_close_ok)),
      "duplicity v pumpdroid_stations_close_ok",
      names(table(pumpdroid_stations_close_ok))[table(pumpdroid_stations_close_ok) > 1])
check(length(pumpdroid_stations_to_be_removed) ==
        length(unique(pumpdroid_stations_to_be_removed)),
      "duplicity v pumpdroid_stations_to_be_removed",
      names(table(pumpdroid_stations_to_be_removed))[table(pumpdroid_stations_to_be_removed) > 1])


# - žádná stanice není ve dvou různých seznamech
check(length(intersect(pumpdroid_stations_close_ok, pumpdroid_stations_to_be_removed)) == 0,
      "pumpdroid_stations_close_ok a pumpdroid_stations_to_be_removed mají stejnou pumpu",
      intersect(pumpdroid_stations_close_ok, pumpdroid_stations_to_be_removed))
check(length(intersect(pumpdroid_stations_close_ok,
                       pumpdroid_stations_to_be_united$target_id)) == 0,
      "pumpdroid_stations_close_ok a pumpdroid_stations_to_be_united$target_id mají stejnou pumpu",
      intersect(pumpdroid_stations_close_ok, pumpdroid_stations_to_be_united$target_id))
check(length(intersect(pumpdroid_stations_to_be_removed,
                       pumpdroid_stations_to_be_united$target_id)) == 0,
      "pumpdroid_stations_to_be_removed a pumpdroid_stations_to_be_united$target_id mají stejnou pumpu",
      intersect(pumpdroid_stations_to_be_removed, pumpdroid_stations_to_be_united$target_id))
check(length(intersect(pumpdroid_stations_close_ok,
                       pumpdroid_stations_to_be_united$source_id)) == 0,
      "pumpdroid_stations_close_ok a pumpdroid_stations_to_be_united$source_id mají stejnou pumpu",
      intersect(pumpdroid_stations_close_ok, pumpdroid_stations_to_be_united$source_id))
check(length(intersect(pumpdroid_stations_to_be_removed,
                       pumpdroid_stations_to_be_united$source_id)) == 0,
      "pumpdroid_stations_to_be_removed a pumpdroid_stations_to_be_united$source_id mají stejnou pumpu",
      intersect(pumpdroid_stations_to_be_removed, pumpdroid_stations_to_be_united$source_id))
check(length(intersect(pumpdroid_stations_to_be_united$target_id,
                       pumpdroid_stations_to_be_united$source_id)) == 0,
      "pumpdroid_stations_to_be_united má stejné pumpy v target_id i source_id",
      intersect(pumpdroid_stations_to_be_united$target_id, pumpdroid_stations_to_be_united$source_id))


# - nikde nesmí být NA
check(sum(is.na(pumpdroid_stations_close_ok)) == 0,
      "pumpdroid_stations_close_ok obsahuje NA")
check(sum(is.na(pumpdroid_stations_to_be_removed)) == 0,
      "pumpdroid_stations_to_be_removed obsahuje NA")
check(sum(map_int(pumpdroid_stations_to_be_united, ~sum(is.na(.)))) == 0,
      "pumpdroid_stations_to_be_united obsahuje NA -- některá hodnota mohla být zadaná špatně")


# - kontrola hodnot feature
allowed_feature_set <- c("all", "price", "name", "location", "sgs", "nonstop")
check(length(setdiff(allowed_feature_set,
                     pumpdroid_stations_to_be_united$feature %>% str_split(", ") %>%
                       unlist() %>%
                       unique())) == 0,
      "pumpdroid_stations_to_be_united$feature obsahuje nepovolená klíčová slova nebo oddělovače",
      setdiff(allowed_feature_set,
              pumpdroid_stations_to_be_united$feature %>% str_split(", ") %>%
                unlist() %>%
                unique()))


# testy ručních oprav jmen čerpacích stanic
# - časové intervaly jednotlivých pokynů se nesmí překrývat
any_date_intersects <- function(tab) {
  dates_intersect <- function(tab) {
    if (nrow(tab) == 1) return(FALSE)
    for (j in (1:(nrow(tab) - 1)))
      for (k in (2:nrow(tab)))
        if (((tab$from[j] <= tab$to[k]) && (tab$from[k] <= tab$to[j])))
          return(TRUE)
    FALSE
  }
  #
  res <- tab %>%
    group_by(id) %>%
    group_map(~tibble(id = .y[["id"]], intersects = dates_intersect(.x))) %>%
    bind_rows()
  setNames(res$intersects, res$id)
}
check(!any(any_date_intersects(pumpdroid_station_names_correction)),
      "pumpdroid_station_names_correction obsahuje pokyny, jejichž časové intervaly se protínají",
      names(any_date_intersects(pumpdroid_station_names_correction)[any_date_intersects(pumpdroid_station_names_correction)]))


# počet chyb
cat("Celkový počet chyb (jejich typů) je", no_of_errors, "\n")






# uložený výsledných tabulek --------------------------------------------------------

stopifnot(no_of_errors == 0)

save(pumpdroid_station_names_to_be_unified,
     pumpdroid_stations_to_be_removed,
     pumpdroid_stations_to_be_united,
     pumpdroid_station_names_correction,
     takeovers_brute_force_correction_table,
     file = file.path(DATADIR, OUTPUTFILE))
